==> circuitpython-Candlesticks-0.6.1.tar.gz: circuitpython-Candlesticks-0.6.1/setup.py <==
# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="circuitpython-Candlesticks",
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    description="CandleSticks for CircuitPython",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # The project's main homepage.
    url="https://github.com/jposada202020/CircuitPython_Candlesticks.git",
    # Author details
    author="Jose David M.",
    author_email="",
    install_requires=["Adafruit-Blinka"],
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    # What does your project relate to?
    keywords="adafruit blinka circuitpython micropython candlesticks stock market displayio",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    py_modules=["candlesticks"],
)

==> circuitpython-Candlesticks-0.7.1.tar.gz: circuitpython-Candlesticks-0.7.1/setup.py <==
# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="circuitpython-Candlesticks",
    use_scm_version=True,
    setup_requires=["setuptools_scm"],
    description="CandleSticks for CircuitPython",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    # The project's main homepage.
    url="https://github.com/jposada202020/CircuitPython_Candlesticks.git",
    # Author details
    author="Jose David M.",
    author_email="cadnlesticks@mailmeto.mozmail.com",
    install_requires=["Adafruit-Blinka"],
    # Choose your license
    license="MIT",
    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries",
        "Topic :: System :: Hardware",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    # What does your project relate to?
    keywords="adafruit blinka circuitpython micropython candlesticks stock market displayio",
    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    py_modules=["circuitpython_Candlesticks"],
)
